]> granicus.if.org Git - neomutt/commitdiff
tidy code
authorRichard Russon <rich@flatcap.org>
Sun, 19 May 2019 10:42:33 +0000 (11:42 +0100)
committerRichard Russon <rich@flatcap.org>
Thu, 23 May 2019 10:57:10 +0000 (11:57 +0100)
- NULL pointers
- variable case
- rename function
- sprinkle credit

94 files changed:
addrbook.c
address/address.c
address/address.h
address/group.c
address/group.h
alias.c
alias.h
commands.c
compose.c
config/address.c
copy.c
edit.c
email/envelope.c
email/envelope.h
email/parse.c
email/rfc2047.c
email/rfc2047.h
hcache/serialize.c
hdrline.c
hdrline.h
hook.c
init.c
main.c
mbox/mbox.c
mutt/string.c
mutt/string2.h
muttlib.c
muttlib.h
mx.c
ncrypt/crypt.c
ncrypt/crypt.h
ncrypt/crypt_gpgme.c
ncrypt/crypt_gpgme.h
ncrypt/crypt_mod.h
ncrypt/cryptglue.c
ncrypt/cryptglue.h
ncrypt/ncrypt.h
ncrypt/pgp.c
ncrypt/pgp.h
ncrypt/pgpinvoke.c
ncrypt/pgpkey.c
ncrypt/pgpkey.h
ncrypt/smime.c
ncrypt/smime.h
pattern.c
pattern.h
query.c
recvcmd.c
remailer.c
send.c
sendlib.c
sendlib.h
smtp.c
smtp.h
sort.c
sort.h
test/address/mutt_addr_cat.c
test/address/mutt_addr_cmp.c
test/address/mutt_addr_copy.c
test/address/mutt_addr_for_display.c
test/address/mutt_addr_free.c
test/address/mutt_addr_new.c
test/address/mutt_addr_valid_msgid.c
test/address/mutt_addr_write.c
test/address/mutt_addrlist_append.c
test/address/mutt_addrlist_copy.c
test/address/mutt_addrlist_dedupe.c
test/address/mutt_addrlist_equal.c
test/address/mutt_addrlist_free.c
test/address/mutt_addrlist_free_all.c
test/address/mutt_addrlist_free_one.c
test/address/mutt_addrlist_has_recips.c
test/address/mutt_addrlist_new.c
test/address/mutt_addrlist_parse.c
test/address/mutt_addrlist_parse2.c
test/address/mutt_addrlist_prepend.c
test/address/mutt_addrlist_qualify.c
test/address/mutt_addrlist_remove.c
test/address/mutt_addrlist_remove_xrefs.c
test/address/mutt_addrlist_search.c
test/address/mutt_addrlist_to_intl.c
test/address/mutt_addrlist_to_local.c
test/address/mutt_addrlist_write.c
test/envelope/mutt_env_cmp_strict.c
test/envelope/mutt_env_merge.c
test/envelope/mutt_env_to_intl.c
test/group/mutt_group_match.c
test/group/mutt_grouplist_add.c
test/group/mutt_grouplist_add_addrlist.c
test/group/mutt_grouplist_remove_addrlist.c
test/main.c
test/parse/mutt_parse_mailto.c
test/parse/mutt_rfc822_parse_line.c
test/rfc2047/rfc2047_encode_addrlist.c

index 3104c5adfa7685cda06477e7db85c4c27b97978f..f4e61e9436eb4ea090ed8e51b56caf7154a60332 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1996-2000,2007 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 8eba231b6c031a5ba4316229b567be838ee5f497..c377112723e54a709551aa07964c682ff75b6247 100644 (file)
@@ -5,6 +5,7 @@
  * @authors
  * Copyright (C) 1996-2000,2011-2013 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 2017 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
@@ -402,7 +403,7 @@ int mutt_addrlist_remove(struct AddressList *al, const char *mailbox)
     return 0;
 
   int rc = -1;
-  struct Address *a, *tmp;
+  struct Address *a = NULL, *tmp = NULL;
   TAILQ_FOREACH_SAFE(a, al, entries, tmp)
   {
     if (mutt_str_strcasecmp(mailbox, a->mailbox) == 0)
@@ -1340,7 +1341,7 @@ void mutt_addrlist_remove_xrefs(const struct AddressList *a, struct AddressList
   if (!a || !b)
     return;
 
-  struct Address *aa, *ab, *tmp;
+  struct Address *aa = NULL, *ab = NULL, *tmp = NULL;
 
   TAILQ_FOREACH_SAFE(ab, b, entries, tmp)
   {
index d68f7cf7ed1dbccd0bb42af71965f4faddcd6df4..e013e898a03d355768b907a2820b447c78342bf1 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2017 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index a23d2c39d9917c0dee83a1427d4e7b2e234a5dd7..891db5a92e9eac9d443c368c513aea714cd23836 100644 (file)
@@ -5,6 +5,7 @@
  * @authors
  * Copyright (C) 2006 Thomas Roessler <roessler@does-not-exist.org>
  * Copyright (C) 2009 Rocco Rutte <pdmef@gmx.net>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
@@ -182,7 +183,7 @@ static void group_add_addrlist(struct Group *g, const struct AddressList *al)
   struct AddressList new = TAILQ_HEAD_INITIALIZER(new);
   mutt_addrlist_copy(&new, al, false);
   mutt_addrlist_remove_xrefs(&g->al, &new);
-  struct Address *a, *tmp;
+  struct Address *a = NULL, *tmp = NULL;
   TAILQ_FOREACH_SAFE(a, &new, entries, tmp)
   {
     mutt_addrlist_append(&g->al, a);
index 5b9cf21d4b7b2e2c7bbd3e5d2f62dc1977d54997..b3fdcb5e1effbf4d1acfce5bd0cd6f71df5a5df4 100644 (file)
@@ -5,6 +5,7 @@
  * @authors
  * Copyright (C) 2006 Thomas Roessler <roessler@does-not-exist.org>
  * Copyright (C) 2009 Rocco Rutte <pdmef@gmx.net>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/alias.c b/alias.c
index 9e20205e7839eeaaed114585356a46b2af29e242..206a22588b66f9f0b9a9841dc355eead6e194647 100644 (file)
--- a/alias.c
+++ b/alias.c
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1996-2002 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
@@ -89,7 +90,7 @@ static void expand_aliases_r(struct AddressList *al, struct ListHead *expn)
           struct AddressList copy = TAILQ_HEAD_INITIALIZER(copy);
           mutt_addrlist_copy(&copy, alias, false);
           expand_aliases_r(&copy, expn);
-          struct Address *a2, *tmp;
+          struct Address *a2 = NULL, *tmp = NULL;
           TAILQ_FOREACH_SAFE(a2, &copy, entries, tmp)
           {
             TAILQ_INSERT_BEFORE(a, a2, entries);
@@ -315,6 +316,8 @@ void mutt_expand_aliases_env(struct Envelope *env)
  * @param[in]  env  Envelope to examine
  * @param[out] pfxp Prefix for the Address, e.g. "To:"
  * @retval ptr AddressList in the Envelope
+ *
+ * @note The caller must NOT free the returned AddressList
  */
 struct AddressList *mutt_get_address(struct Envelope *env, const char **pfxp)
 {
diff --git a/alias.h b/alias.h
index 798013628ffb08c177c57bf945d5a9850974ee23..48efa6d75cc45f9c88f5280cb06925ca33a63ca0 100644 (file)
--- a/alias.h
+++ b/alias.h
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2017 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index e730a1fabeaf140d22909677d8a9d6ea296ad2c7..9d43aa35ed22296f0be27f9a68512069e48b93d4 100644 (file)
@@ -5,6 +5,7 @@
  * @authors
  * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 2000-2004,2006 Thomas Roessler <roessler@does-not-exist.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index e47f8741b733e7aaf68719f5850f830a41035617..19ad6c9912140d87ba829362e1e6e36a47eeaec9 100644 (file)
--- a/compose.c
+++ b/compose.c
@@ -5,6 +5,7 @@
  * @authors
  * Copyright (C) 1996-2000,2002,2007,2010,2012 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 2004 g10 Code GmbH
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index b7c3cfad84db0f8b0c8d19e0df5a61865e2165e3..5544e550c01b5f382d291aa5808993674da9ec20 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2017-2018 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/copy.c b/copy.c
index 660aeded76524789581edcf5ada7abeff6683087..cd93a735d92c2a750c28391bc1b3b561cde71031 100644 (file)
--- a/copy.c
+++ b/copy.c
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1996-2000,2002,2014 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/edit.c b/edit.c
index 21f9affc6af27be91b813deb369a32e282762cde..bf2e17ddc6fe29b41dfe8e673ef93dd46dbcc7d4 100644 (file)
--- a/edit.c
+++ b/edit.c
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index f4ceeb245aa63652bf19f5097c339aab892f55a2..17fd2fa17eaddb2c7e303d4d5d8a526286c7e119 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2017 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index cc0a1262f2110134ccacbf36c747827e2a10209c..2d319c299cc9a901568014f61715b57ee54f4a7c 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2017 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 644f22cb7b3e15da53b9b737d64e4bbf0b812a17..618b3b2de3ced6d6716734ab8e378fe275d7585f 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2018 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 3482374e8da5241070579a8a16a59d83a0f05924..bb98b13dae74d56cca19e3074c5a3c0cf5360c1f 100644 (file)
@@ -5,7 +5,7 @@
  * @authors
  * Copyright (C) 1996-2000,2010 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 2000-2002 Edmund Grimley Evans <edmundo@rano.org>
- * Copyright (C) 2018 Pietro Cerutti <gahr@gahr.ch>
+ * Copyright (C) 2018-2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index ef194c4a5c3c83131621f8666011020f11a816de..933733bf195adf914ac015c3f1308822310896d2 100644 (file)
@@ -5,7 +5,7 @@
  * @authors
  * Copyright (C) 1996-2000,2010 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 2000-2002 Edmund Grimley Evans <edmundo@rano.org>
- * Copyright (C) 2018 Pietro Cerutti <gahr@gahr.ch>
+ * Copyright (C) 2018-2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 46807d1f73a55840640df0c4f2252b2bf3b3cd7c..cec5f782fe14d21ceae54788c3bdfe2dd28740b7 100644 (file)
@@ -6,7 +6,7 @@
  * Copyright (C) 2004 Thomas Glanzmann <sithglan@stud.uni-erlangen.de>
  * Copyright (C) 2004 Tobias Werth <sitowert@stud.uni-erlangen.de>
  * Copyright (C) 2004 Brian Fundakowski Feldman <green@FreeBSD.org>
- * Copyright (C) 2016 Pietro Cerutti <gahr@gahr.ch>
+ * Copyright (C) 2016-2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index b0f9de0535c7e7b0c41a9329036eb8425136b6b0..1ccb3fa0fa38edcb3b9f6e7874a4b6d057c8616c 100644 (file)
--- a/hdrline.c
+++ b/hdrline.c
@@ -6,6 +6,7 @@
  * Copyright (C) 1996-2000,2002,2007 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 2016 Richard Russon <rich@flatcap.org>
  * Copyright (C) 2016 Ian Zimmerman <itz@primate.net>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index a1801817150fe62283015e630a6532040cc3e6d3..f9171cfad083868e513cac7146b575b09bd26889 100644 (file)
--- a/hdrline.h
+++ b/hdrline.h
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2018 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/hook.c b/hook.c
index 62c8f80361c38dd73e3bf53a0fcbc797b63c3cb3..71a7f5a6faeeac50c6055e02023f6059b814c1ad 100644 (file)
--- a/hook.c
+++ b/hook.c
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1996-2002,2004,2007 Michael R. Elkins <me@mutt.org>, and others
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/init.c b/init.c
index 807c2d5a16da024152e6a66f0f1dac5c3671a096..3dc1f8964db16b754332805457d93fc93f141ed5 100644 (file)
--- a/init.c
+++ b/init.c
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1996-2002,2010,2013,2016 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/main.c b/main.c
index a8002d89b53386802e5f9e7a6b681b94f42d2042..2805ae14efc7cd89d36ae60405ade9b792fe4558 100644 (file)
--- a/main.c
+++ b/main.c
@@ -6,6 +6,7 @@
  * Copyright (C) 1996-2007,2010,2013 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 1999-2007 Thomas Roessler <roessler@does-not-exist.org>
  * Copyright (C) 2004 g10 Code GmbH
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index fa71c5133cb9b57167b6f216e124910d9e22be91..248bf2e1b9383549cfdbe1b2178825c8706bf935 100644 (file)
@@ -5,6 +5,7 @@
  * @authors
  * Copyright (C) 1996-2002,2010,2013 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 2018 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 7869dcfc9650608702875c4484d0f20d8d301f7c..f8ac0609828a69d7078cb3a0f939df9b226706d3 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2017 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 62daeb14d0834af72bb494cb538355c0b3269ab9..a0edd243ec6a4096cdedf87a9f0a51c9194fb454 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2017 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 4f60a5e13355d551155b0cc6e9a02011bbf90d46..8d14e899a4edc0ab2ab308f409f774949ac7fa20 100644 (file)
--- a/muttlib.c
+++ b/muttlib.c
@@ -5,6 +5,7 @@
  * @authors
  * Copyright (C) 1996-2000,2007,2010,2013 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 1999-2008 Thomas Roessler <roessler@does-not-exist.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index c4c76e450c1dbe9c93d897bd4dfc939a1f793e23..ce09d711f5c7d982d94285d2f0c85c059edda47a 100644 (file)
--- a/muttlib.h
+++ b/muttlib.h
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2018 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/mx.c b/mx.c
index ad77c7256ebaaab7637ab8c7fc1dbc5b400810fb..6c341feba88927c797f083929a9cfd6893735809 100644 (file)
--- a/mx.c
+++ b/mx.c
@@ -6,6 +6,7 @@
  * Copyright (C) 1996-2002,2010,2013 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 1999-2003 Thomas Roessler <roessler@does-not-exist.org>
  * Copyright (C) 2016-2018 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index b76be60c8716d4730dbf2d0d3b946eb458e34711..00be27d2a74e2d02a7f9f178ea5e8f097b246072 100644 (file)
@@ -9,6 +9,7 @@
  * Copyright (C) 2001 Oliver Ehli <elmy@acm.org>
  * Copyright (C) 2003 Werner Koch <wk@gnupg.org>
  * Copyright (C) 2004 g10code GmbH
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index b210e88322e9713941e064c2a3ab271302b929c9..a5591279590002ea1548656cdc08e70b89f563ce 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2017 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 046b11933080ae6359d31f7cf65c408d202cac34..85f4221f11a49177ebb1646772d46ef762f1ffa7 100644 (file)
@@ -9,6 +9,7 @@
  * Copyright (C) 2001 Oliver Ehli <elmy@acm.org>
  * Copyright (C) 2002-2004, 2018 g10 Code GmbH
  * Copyright (C) 2010,2012-2013 Michael R. Elkins <me@sigpipe.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
@@ -5141,7 +5142,7 @@ static char *find_keys(struct AddressList *addrlist, unsigned int app, bool oppe
 {
   struct ListHead crypt_hook_list = STAILQ_HEAD_INITIALIZER(crypt_hook_list);
   struct ListNode *crypt_hook = NULL;
-  const char *keyID = NULL;
+  const char *keyid = NULL;
   char *keylist = NULL;
   size_t keylist_size = 0;
   size_t keylist_used = 0;
@@ -5167,32 +5168,32 @@ static char *find_keys(struct AddressList *addrlist, unsigned int app, bool oppe
 
       if (crypt_hook)
       {
-        keyID = crypt_hook->data;
+        keyid = crypt_hook->data;
         enum QuadOption ans = MUTT_YES;
         if (!oppenc_mode && C_CryptConfirmhook)
         {
-          snprintf(buf, sizeof(buf), _("Use keyID = \"%s\" for %s?"), keyID, p->mailbox);
+          snprintf(buf, sizeof(buf), _("Use keyID = \"%s\" for %s?"), keyid, p->mailbox);
           ans = mutt_yesorno(buf, MUTT_YES);
         }
         if (ans == MUTT_YES)
         {
-          if (crypt_is_numerical_keyid(keyID))
+          if (crypt_is_numerical_keyid(keyid))
           {
-            if (strncmp(keyID, "0x", 2) == 0)
-              keyID += 2;
+            if (strncmp(keyid, "0x", 2) == 0)
+              keyid += 2;
             goto bypass_selection; /* you don't see this. */
           }
 
           /* check for e-mail address */
           mutt_addrlist_free_all(&hookal);
-          if (strchr(keyID, '@') && (mutt_addrlist_parse(&hookal, keyID) != 0))
+          if (strchr(keyid, '@') && (mutt_addrlist_parse(&hookal, keyid) != 0))
           {
             mutt_addrlist_qualify(&hookal, fqdn);
             p = TAILQ_FIRST(&hookal);
           }
           else if (!oppenc_mode)
           {
-            k_info = crypt_getkeybystr(keyID, KEYFLAG_CANENCRYPT, app, &forced_valid);
+            k_info = crypt_getkeybystr(keyid, KEYFLAG_CANENCRYPT, app, &forced_valid);
           }
         }
         else if (ans == MUTT_NO)
@@ -5232,13 +5233,13 @@ static char *find_keys(struct AddressList *addrlist, unsigned int app, bool oppe
         return NULL;
       }
 
-      keyID = crypt_fpr_or_lkeyid(k_info);
+      keyid = crypt_fpr_or_lkeyid(k_info);
 
     bypass_selection:
-      keylist_size += mutt_str_strlen(keyID) + 4 + 1;
+      keylist_size += mutt_str_strlen(keyid) + 4 + 1;
       mutt_mem_realloc(&keylist, keylist_size);
       sprintf(keylist + keylist_used, "%s0x%s%s", keylist_used ? " " : "",
-              keyID, forced_valid ? "!" : "");
+              keyid, forced_valid ? "!" : "");
       keylist_used = mutt_str_strlen(keylist);
 
       key_selected = true;
index 7969950754dd46413fe73f89443d77f8035fb4c4..7e0efc1eba6aee3a45f1ba8eb9ae6d6f179e230e 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2004 g10 Code GmbH
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 59f510dc4a3de935506c0cedcdfd5b8d0d53730f..508976c5ee0bdb3e31b71428259124740ac49876 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2017 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index cabc2768aeaac4739373fcfe1a522deeaad84348..d36ab42c64a53f7a4f7fb3d8148454a526efe9e2 100644 (file)
@@ -5,6 +5,7 @@
  * @authors
  * Copyright (C) 2003 Werner Koch <wk@gnupg.org>
  * Copyright (C) 2004 g10 Code GmbH
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 82a7e7be50e20ee23a167b2de87ffb991890124e..193fea9c960490bac6d2692beeb005ad28c83e20 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2017 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index c51828c5301a7877cef44da8c375d9f1b80e62f6..779a6cc24ba83c91cf1cc3f4bd2b7fdb73f1c369 100644 (file)
@@ -5,6 +5,7 @@
  * @authors
  * Copyright (C) 2003 Werner Koch <wk@gnupg.org>
  * Copyright (C) 2004 g10code GmbH
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 59ad8a89a60b052ea9308b9a570f8d937c27e4a4..68c304c9704a32ead02ed3896ce9aa5e67ba03a1 100644 (file)
@@ -6,6 +6,7 @@
  * Copyright (C) 1996-1997,2000,2010 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 1998-2005 Thomas Roessler <roessler@does-not-exist.org>
  * Copyright (C) 2004 g10 Code GmbH
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
@@ -1411,7 +1412,7 @@ char *pgp_class_find_keys(struct AddressList *addrlist, bool oppenc_mode)
 {
   struct ListHead crypt_hook_list = STAILQ_HEAD_INITIALIZER(crypt_hook_list);
   struct ListNode *crypt_hook = NULL;
-  const char *keyID = NULL;
+  const char *keyid = NULL;
   char *keylist = NULL;
   size_t keylist_size = 0;
   size_t keylist_used = 0;
@@ -1435,32 +1436,32 @@ char *pgp_class_find_keys(struct AddressList *addrlist, bool oppenc_mode)
 
       if (crypt_hook)
       {
-        keyID = crypt_hook->data;
+        keyid = crypt_hook->data;
         enum QuadOption ans = MUTT_YES;
         if (!oppenc_mode && C_CryptConfirmhook)
         {
-          snprintf(buf, sizeof(buf), _("Use keyID = \"%s\" for %s?"), keyID, p->mailbox);
+          snprintf(buf, sizeof(buf), _("Use keyID = \"%s\" for %s?"), keyid, p->mailbox);
           ans = mutt_yesorno(buf, MUTT_YES);
         }
         if (ans == MUTT_YES)
         {
-          if (crypt_is_numerical_keyid(keyID))
+          if (crypt_is_numerical_keyid(keyid))
           {
-            if (strncmp(keyID, "0x", 2) == 0)
-              keyID += 2;
+            if (strncmp(keyid, "0x", 2) == 0)
+              keyid += 2;
             goto bypass_selection; /* you don't see this. */
           }
 
           /* check for e-mail address */
           mutt_addrlist_free_all(&hookal);
-          if (strchr(keyID, '@') && (mutt_addrlist_parse(&hookal, keyID) != 0))
+          if (strchr(keyid, '@') && (mutt_addrlist_parse(&hookal, keyid) != 0))
           {
             mutt_addrlist_qualify(&hookal, fqdn);
             p = TAILQ_FIRST(&hookal);
           }
           else if (!oppenc_mode)
           {
-            k_info = pgp_getkeybystr(keyID, KEYFLAG_CANENCRYPT, PGP_PUBRING);
+            k_info = pgp_getkeybystr(keyid, KEYFLAG_CANENCRYPT, PGP_PUBRING);
           }
         }
         else if (ans == MUTT_NO)
@@ -1500,12 +1501,12 @@ char *pgp_class_find_keys(struct AddressList *addrlist, bool oppenc_mode)
         return NULL;
       }
 
-      keyID = pgp_fpr_or_lkeyid(k_info);
+      keyid = pgp_fpr_or_lkeyid(k_info);
 
     bypass_selection:
-      keylist_size += mutt_str_strlen(keyID) + 4;
+      keylist_size += mutt_str_strlen(keyid) + 4;
       mutt_mem_realloc(&keylist, keylist_size);
-      sprintf(keylist + keylist_used, "%s0x%s", keylist_used ? " " : "", keyID);
+      sprintf(keylist + keylist_used, "%s0x%s", keylist_used ? " " : "", keyid);
       keylist_used = mutt_str_strlen(keylist);
 
       key_selected = true;
index d4e8dbe98db725805a43e7c4f74d7cc32a5315a7..46a308e612216525a40007ad167bda1d83e9f781 100644 (file)
@@ -6,6 +6,7 @@
  * Copyright (C) 1996-1997 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 1999-2003 Thomas Roessler <roessler@does-not-exist.org>
  * Copyright (C) 2004 g10 Code GmbH
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 9b6042239f03329644ba8d5ce036d6ce757d4edb..42309f6df8674798414e11fdfb18ee273c41c48f 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1997-2003 Thomas Roessler <roessler@does-not-exist.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index ab19b87cc20251a34c157f06f54be3703b285cf8..1b1ccf7470cdb4da352340a243835a707921d22d 100644 (file)
@@ -5,6 +5,7 @@
  * @authors
  * Copyright (C) 1996-1997,2007 Michael R. Elkins <me@mutt.org>
  * Copyright (c) 1998-2003 Thomas Roessler <roessler@does-not-exist.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 748b9f911bca4d396555265c3a3cc87556ef03d5..dd355b34f50fe66efbf08db4ba5a73c57b47cd1b 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2017 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 37f90fd5d439846d4a6b4007612b2afa7ae8097b..c95de3d63dd7c8079eeca9f3933dafc7e9f858b0 100644 (file)
@@ -6,6 +6,7 @@
  * Copyright (C) 2001-2002 Oliver Ehli <elmy@acm.org>
  * Copyright (C) 2002 Mike Schiraldi <raldi@research.netsol.com>
  * Copyright (C) 2004 g10 Code GmbH
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
@@ -1035,7 +1036,7 @@ void smime_class_getkeys(struct Envelope *env)
 char *smime_class_find_keys(struct AddressList *al, bool oppenc_mode)
 {
   struct SmimeKey *key = NULL;
-  char *keyID = NULL, *keylist = NULL;
+  char *keyid = NULL, *keylist = NULL;
   size_t keylist_size = 0;
   size_t keylist_used = 0;
 
@@ -1057,10 +1058,10 @@ char *smime_class_find_keys(struct AddressList *al, bool oppenc_mode)
       return NULL;
     }
 
-    keyID = key->hash;
-    keylist_size += mutt_str_strlen(keyID) + 2;
+    keyid = key->hash;
+    keylist_size += mutt_str_strlen(keyid) + 2;
     mutt_mem_realloc(&keylist, keylist_size);
-    sprintf(keylist + keylist_used, "%s%s", keylist_used ? " " : "", keyID);
+    sprintf(keylist + keylist_used, "%s%s", keylist_used ? " " : "", keyid);
     keylist_used = mutt_str_strlen(keylist);
 
     smime_free_key(&key);
index c0c8d6a99ec23ec5e177c53b550f4dcd5e6f2d74..bcc0d8cab89355bf8cf78291ba8624151891d978 100644 (file)
@@ -5,6 +5,7 @@
  * @authors
  * Copyright (C) 2001-2002 Oliver Ehli <elmy@acm.org>
  * Copyright (C) 2004 g10 Code GmbH
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 9f7ffac9a7719dc02a69322d846407dbf3d2f56b..a1e3beee38d93aa5d1892baa93e1baf09c506dfa 100644 (file)
--- a/pattern.c
+++ b/pattern.c
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1996-2000,2006-2007,2010 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 5e722c796c87cfe91fc446ff46fb77564742ab06..13b73aaea0061ecdd60b2783cccbc18f182c2f2a 100644 (file)
--- a/pattern.h
+++ b/pattern.h
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2017 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
--- a/recvcmd.c
+++ b/recvcmd.c
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1999-2004 Thomas Roessler <roessler@does-not-exist.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index a4556d1326419cf1a2725fa3512593a6f9b5dcf2..5fc48b3a0fe9b367c708422c027d212cc1638763 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1999-2001 Thomas Roessler <roessler@does-not-exist.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/send.c b/send.c
index 5b6ad054fd79c3316edd5f51071af84258f69bad..295dc5d4d50a93946117a695a279b0553c216eb3 100644 (file)
--- a/send.c
+++ b/send.c
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1996-2002,2004,2010,2012-2013 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
@@ -158,7 +159,7 @@ static void append_signature(FILE *fp)
  */
 static void remove_user(struct AddressList *al, bool leave_only)
 {
-  struct Address *a, *tmp;
+  struct Address *a = NULL, *tmp = NULL;
   TAILQ_FOREACH_SAFE(a, al, entries, tmp)
   {
     if (mutt_addr_is_user(a) && (!leave_only || TAILQ_NEXT(a, entries)))
index 338ae877b4d9550a02df6a201a132d183c4c6329..4ce14b83623676451f2fdbf025b29ed63ce28912 100644 (file)
--- a/sendlib.c
+++ b/sendlib.c
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1996-2002,2009-2012 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 5b7b547fd9b63e6b82d797c39516f1a7f2bbfdf1..2e2f79c9cb8bf7ada57cd5b2be0b16d13d3b6447 100644 (file)
--- a/sendlib.h
+++ b/sendlib.h
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2018 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/smtp.c b/smtp.c
index 9366877178f8f41890552033bfbc540c8d9f23f2..a64e14a2ecf29d80f1f8ce9354335dff6d0954ad 100644 (file)
--- a/smtp.c
+++ b/smtp.c
@@ -5,6 +5,7 @@
  * @authors
  * Copyright (C) 2002 Michael R. Elkins <me@mutt.org>
  * Copyright (C) 2005-2009 Brendan Cully <brendan@kublai.com>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/smtp.h b/smtp.h
index 246c50ac02824ca943a1092a47eb9ed4ae6907b5..cf74ed8b3ae13f0ba7b0aa113ef6dff868ee7897 100644 (file)
--- a/smtp.h
+++ b/smtp.h
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2018 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/sort.c b/sort.c
index f64d2f82eda7a14aa44b020cc7ed73a3c6faa948..fe9743e27332f03b43854ecd8cdb39d819ff3bab 100644 (file)
--- a/sort.c
+++ b/sort.c
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/sort.h b/sort.h
index 8516f528e2eabf2a808939d9d765c2c793ad19e0..1eee0719c7ad21b058a486db399dd00874f1f218 100644 (file)
--- a/sort.h
+++ b/sort.h
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 1db734740e5874678ffea9f6e1f55c7cdcde83a7..02b41be1b6ed9881122d63f2de3d62c3fa4e1a29 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index c3420528a03a7c57427b39d7f8c99a36e90dcd83..2fb99cbefa9955f8016159039a86e94f0c5e5352 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 492ab17933e51bc3ecc0ce9982c38cb5a6f729e0..7538011127d5b0f51863ae266cdbf1e99842f684 100644 (file)
@@ -4,6 +4,8 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 98eb1fc0dcd3f9c0636da5999267f994447fccab..9de51a0e2c8da97e67afcaaffed045ab5a877623 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index d3075227811f32f711fbbfbaa334b955796e6746..e4cfe5293f3d59ede64d9629aae16ad2afa08353 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index ddc01d7798e22bc1749442cd00fa883c2e82ed0c..e49c178c37f95472efe9375b368295de9fbc64eb 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 2446984a5c85042fb5352bf262a6e988fe88b2e3..6d19a6efdb84c394fb17388102b4696e4478b491 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index b75181acae66b7d2174d5a62c4e90e3947b9ba58..61eef6d847aa9ec5b6fa8aa812b61c4d936b1226 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index b763cc759015f3c6d1df9413d5ec7cfed26228e7..e6eeea243994616bcc9901292c6a06bbac0176d2 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 023f9d47cde9b80c4fa24a75133c9aa004f7d6b6..141070f4d8876ffca29129340dba5a12530dd2b5 100644 (file)
@@ -4,6 +4,8 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index dac79f8c16d8d87547bf3fd31869775203902dc8..571f54b77f943d4bbc737d16e8dfcb745f4e5d28 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 31e2032d164195ecd3b40f07f462f3fc8f79f81f..9c25b8583cce8a98ed2705c0c2cf77f2f91e090a 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 2f20890843f482c812890d2594f594bbadf3521c..029bb5712b9c2edf4ebebd61e51ec825aec209fe 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 63dc48d3451eea10b59533c45a0452482862ea79..cfe9b79fa088dd579d6d4c1bbe40920f5ba7ca8a 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index f58c1f6ba03790e7ee550e18d308c2c49e23e3e5..953f6dfc6e944213ac8b7b06bfa62f99989bd299 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index ebe75e1f223a4a322a8011c2d5b0ad31c03f967d..c641562b567754a830c401bad58e556ca66735c7 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 70314070a5c174338c1c65ad308791ee6b5a4ad7..765ef39cae416a305cd46bd42c840384eeb15d22 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 77f93eedd223d4cba5120ee4dda6808704ec8601..c535bfcc68fc65937c89e1831227eb5bb44abfef 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 73ae99bbe9219779ef44659763645eec18d569b0..1b5242b3e9fa0513251aff00bf497207a78d4ebe 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 0896c39b712be0c3513eb91ce5606d10514ada88..c8f58f5568679474ad1aff1796a628f217e7e1b4 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 8dcdb90a6e90ff465d36c83161fdf0e0c9da32ef..91be5c2109e8e65f1c17ee1325a59a21dbcedc22 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index d6fbe5ca8a952a613cfc9d5bedf70e46271add8f..508532d4087f8e86a9a910189456cd0e61d9cb98 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index b3297610299934b7f1f69b209cf2b5c1226235f4..033efdc838803b95f6ad43d3ad529d959b1abb94 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index b547d4889521972e1431a48c17eb5ba57613a91e..2ed87a8f78ff04dab712ea14100b633dfa6486ec 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 15d7f7546c26dda765807c518ceb18b57de71ec9..d31649881731dea56de0616cccdeaa42ca0ad6ba 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 9488f50862a100598e3c215ae13a6c4a98e6f0ad..e18d2715e2cb08a3230d805aad137f4699c792cd 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 3c38e903faef15a72243142aa5e06f6aa3f2ef55..6bf5dcd8d3d4377c9365ffa3197cdab6abe1d9ee 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 41e64e5847a4ca46741a224070da4b9f4885f221..dad8ca232983bd384848f3e12272bd92aa6e6fff 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 89bf6cf5cdbf673a6605a7935cd796218ecdd888..350a0e2089118464a7cb4024850d6ae9b0928da0 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 854b4d3d99b0a9483a5c28a1c74941179d068588..9c36a3e27273a9b2684a6a78c9dfa38791f95098 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index dd3e4eb3aa4617873f8f51c6cbe62ef4a335b729..61c5f46664397b03dc2b0818acbb4e902e71bc0f 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index f844582611a258360e5fbbe48fef3ff19919e697..be3a180b926ff45c36c6a6463036bfa2f7437c37 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index d7d59ebf82f48815c94d3cde49606805072c607d..3c5d67f6e4cb4b9b1b621d9ba0189704f251791a 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index c0d1cc1058755377c0613fcd5870342d5255fc65..1a8182f1cbf76144ce7db53cbca1de7c9e48449e 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 06fe780f77bea47975f8e227ff34381b8302dc42..7388eabcb6b0d88198431a8d3bbae14a89330e4c 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2018 Pietro Cerutti <gahr@gahr.ch>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index af5ce50cee25ec7755cdb8ab7f825f3058b2c96f..2b62a294416869fd5e903319309926a04244052d 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index 75109abd9775c423d7640dbe7922aad92ff4e609..21013cdd2aed029c53e1043095310f71e2489166 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
index c289ec7d418428cc3ab65dad991d909f2996e0f6..75f962fb1ab098b5183b0a0c09b6ea74b5467152 100644 (file)
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 2019 Richard Russon <rich@flatcap.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/query.c b/query.c
index 323cea054a9f96bd36f5c3472270b1a5f586cf3c..90d075302a3c19095caae803ab99034e9cfdfa3e 100644 (file)
--- a/query.c
+++ b/query.c
@@ -4,6 +4,7 @@
  *
  * @authors
  * Copyright (C) 1996-2000,2003,2013 Michael R. Elkins <me@mutt.org>
+ * Copyright (C) 2019 Pietro Cerutti <gahr@gahr.ch>
  *
  * @copyright
  * This program is free software: you can redistribute it and/or modify it under
@@ -87,6 +88,7 @@ static const struct Mapping QueryHelp[] = {
 /**
  * result_to_addr - Turn a Query into an Address
  * @param r Query to use
+ * @retval ptr Newly allocated AddressList
  */
 static struct AddressList *result_to_addr(struct Query *r)
 {
@@ -109,10 +111,10 @@ static struct AddressList *result_to_addr(struct Query *r)
 }
 
 /**
* new_query - Create a new query
  * @retval A newly allocated query
  */
-static struct Query *new_query(void)
+static struct Query *query_new(void)
 {
   struct Query *query = mutt_mem_calloc(1, sizeof(struct Query));
   TAILQ_INIT(&query->addr);
@@ -185,12 +187,12 @@ static struct Query *run_query(char *s, int quiet)
     {
       if (!first)
       {
-        first = new_query();
+        first = query_new();
         cur = first;
       }
       else
       {
-        cur->next = new_query();
+        cur->next = query_new();
         cur = cur->next;
       }
 
@@ -109,10 +111,10 @@ static struct AddressList *result_to_addr(struct Query *r)
 
 /**
- * new_query - Create a new query
+ * query_new - Create a new query
  * @retval A newly allocated query
  */
index 564e152fb60ce4d381003543cda4db12b3c91891..b1272102e4966099fc8c4f4a9ab943ab5828e147 100644 (file)